#include <stdio.h>
#include "stimul.h"

// square layer of width 1 cm
#define WX 0.01
#define WY WX

// use grids of 100 x 100
#define NX 100
#define NY NX

int main()
{
  stml_grid *g = stml_grid_new(NX,NY);
  stml_multilayer *p = stml_multilayer_new(WX,WY,NX,NY); 

  // first layer defines a heat flux of 1 W/mm^2 (top side)
  stml_grid_set(g,1e6);
  stml_multilayer_sources(p,g,"top side");

  // second layer defines a slab of thickness 1 mm and thermal conductivity 400 W/mK
  stml_multilayer_slab(p,1e-3,400);

  // last layer defines an isothermal plane at 20 degrees Celsius (bottom side)
  stml_multilayer_isotherm(p,20,"bottom side");

  // finalize multilayer
  stml_multilayer_finalize(p);

  // get temperature at the center of the top side
  stml_multilayer_solve(p,"top side",g);
  printf("Temperature = %f\n",stml_grid_read(g,NX/2,NY/2));

  // get heat flux at the center of the bottom side
  stml_multilayer_solve(p,"bottom side",g);
  printf("Heat flux = %f\n",stml_grid_read(g,NX/2,NY/2));

  stml_grid_free(g);
  stml_multilayer_free(p);
}
