/*
This example reproduces the results of Figure 5 in the ATMI manual
(http://www.irisa.fr/caps/projects/ATMI)
*/

#include <stdio.h>
#include <stdlib.h>
#include "stimul.h"


#define NX 500
#define NY 500
#define LX 0.05
#define LY LX
#define SX 0.0030
#define SY 0.0006
#define EX (LX/NX)
#define EY (LY/NY)
#define CHIPX 0.01
#define CHIPY 0.01

enum location {center,edge,corner};
double ki[3] = {1.,3.,10.};
double a[3] = {0.001,0.002,0.003};

double t[3][3][3];


void coord(enum location p, double a, double *i1, double *j1, double *i2, double *j2)
{
  switch (p) {
  case center: *i1 = (NX/2)*(1-a/CHIPX); *j1 = *i1; break;
  case edge: *i1 = (NX/2)*(1-a/CHIPX); *j1 = 0; break;
  case corner: *i1 = 0; *j1 = 0; break;
  }
  *i2 = *i1+NX*a/CHIPX-1; 
  *j2 = *j1+NY*a/CHIPY-1;
}


void temperature(int i)
{
  double q,i1,i2,j1,j2,x0,y0;
  enum location loc;
  int j;

  stml_stack *s = stml_stack_new();
  stml_grid *g = stml_grid_new(NX,NY);

  stml_grid_set(g,0);

  stml_stack_start(s,CHIPX,CHIPY,NX,NY,NULL,0,"ML1");
  stml_stack_add(s,0.03,0.03,NX,NY,0,0,"ML2");

  stml_stack_interface(s,"ML1",0.001);
  stml_stack_sources(s,"ML1",NULL,"source");
  stml_stack_slab(s,"ML1",5e-4,120);
  stml_stack_slab(s,"ML1",1e-4,ki[i]);
  stml_stack_slab(s,"ML2",0.001,400);
  stml_stack_interface(s,"ML2",200);
  stml_stack_finalize(s,NULL,0);

  for (j=0; j<3; j++) {
    q = 2./(a[j]*a[j]);
    for (loc=0; loc<3; loc++) {
      coord(loc,a[j],&i1,&j1,&i2,&j2);
      stml_grid_rectangle(g,i1,j1,i2,j2,q);
      stml_stack_modify(s,"ML1","source",g);
      stml_stack_solve(s,1e-3);
      stml_stack_solution(s,"ML1","source",g);
      x0 = 0.5*(i1+i2+1);
      y0 = 0.5*(j1+j2+1);
      t[j][i][loc] = stml_grid_read(g,x0,y0);
    }
  }
  stml_stack_free(s);
  stml_grid_free(g);
}


int main()
{
  int i,j,k;
  for (i=0; i<3; i++) {
    temperature(i);
  }
  for (i=0; i<3; i++) {
    for (j=0; j<3; j++) {
      printf("side= %.3f  intk= %5.1f :",a[i],ki[j]);
      for (k=0; k<3; k++) {
	printf("%8.2f ",t[i][j][k]);
      }
      printf("\n");
    }
  }

}
