#include <stdio.h>
#include "stimul.h"

#define AMBIENT 30

// use grids of 160 x 160
#define NX 160
#define NY NX

int main()
{
  stml_stack *s = stml_stack_new();
  stml_grid *g = stml_grid_new(NX,NY);

  // set the two square heat sources in grid g
  stml_grid_set(g,0);
  stml_grid_rectangle(g,0,NX/2-NX/8,NX/4-1,NX/2+NX/8-1,1e6);
  stml_grid_rectangle(g,NX-1,NX/2-NX/8,NX-NX/4,NX/2+NX/8-1,1e6);

  // define 3 multilayers
  stml_stack_start(s,0.016,0.016,NX,NY,NULL,AMBIENT,"ML1");
  stml_stack_add(s,0.03,0.03,NX,NY,0,AMBIENT,"ML2");
  stml_stack_add(s,0.06,0.06,NX,NY,0,AMBIENT,"ML3");
  // first multilayer
  stml_stack_interface(s,"ML1",10);
  stml_stack_slab(s,"ML1",1e-5,12);
  stml_stack_sources(s,"ML1",g,"circuits");
  stml_stack_slab(s,"ML1",5e-4,100);
  stml_stack_slab(s,"ML1",5e-5,5);
  // second multilayer
  stml_stack_slab(s,"ML2",1e-3,400);
  stml_stack_slab(s,"ML2",5e-5,5);
  // third multilayer
  stml_stack_slab(s,"ML3",5e-3,400);
  stml_stack_interface(s,"ML3",500);
  // finalize and solve
  stml_stack_finalize(s,NULL,AMBIENT);
  stml_stack_solve(s,1e-3);
  // output temperature map of the source layer
  stml_stack_solution(s,"ML1","circuits",g);
  stml_grid_print(g);

  stml_grid_free(g);
  stml_stack_free(s);
}
