/*
This example reproduces the results of Figure 9 in the following reference:
B. Wang and O. Mazumder,
"Accelerated chip-level thermal analysis using multilayer Green's function",
IEEE Transactions on Computer-Aided Design of Integrated Circuits and Systems,
Vol. 26, No. 2, February 2007.
*/

#include <stdio.h>
#include "stimul.h"

#define NX 100
#define NY NX
#define UL (NX/10)
#define SQA (2e-4*2e-4)

void setg(stml_grid *g, double v[7])
{
  stml_grid_set(g,v[0]);
  stml_grid_rectangle(g,0,0,UL-1,UL-1,v[1]);
  stml_grid_rectangle(g,9*UL,0,10*UL-1,UL-1,v[2]);
  stml_grid_rectangle(g,4*UL,2*UL,6*UL-1,3*UL-1,v[3]);
  stml_grid_rectangle(g,4*UL,7*UL,6*UL-1,8*UL-1,v[4]);
  stml_grid_rectangle(g,0,9*UL,UL-1,10*UL-1,v[5]);
  stml_grid_rectangle(g,9*UL,9*UL,10*UL-1,10*UL-1,v[6]);
}


#define HOMOGENEOUS__
#define TOPSURFACE__


int main()
{
  double v[7];
  stml_grid *g = stml_grid_new(NX,NY);
  stml_multilayer *p = stml_multilayer_new(2e-3,2e-3,NX,NY);

#ifdef HOMOGENEOUS
  v[0]=3.5; v[1]=v[6]=5; v[2]=v[5]=8; v[3]=v[4]=10;
  setg(g,v);
#else 
  stml_grid_set(g,0);
#endif
  stml_multilayer_temperature(p,g,"BC1"); 
  stml_multilayer_interface(p,1387);
#ifdef HOMOGENEOUS
  stml_grid_set(g,0);
#else
  v[0]=0; v[1]=v[6]=0.15/SQA; v[2]=v[5]=0.12/SQA; v[3]=v[4]=0.6/(2*SQA); 
  setg(g,v);
#endif
  stml_multilayer_sources(p,g,"sources");
  stml_multilayer_slab(p,250e-6,98.4);
  stml_multilayer_slab(p,30e-6,16.2);
  stml_multilayer_slab(p,220e-6,261.5);
  stml_multilayer_sources(p,NULL,"bottom"); // just here for measurement
  stml_multilayer_interface(p,8675); 
#ifdef HOMOGENEOUS
  stml_multilayer_isotherm(p,2,"BC2"); 
#else
  stml_multilayer_isotherm(p,0,"BC2");
#endif

  stml_multilayer_finalize(p);

#ifdef TOPSURFACE
  stml_multilayer_solve(p,"bottom",g);
#else
  stml_multilayer_solve(p,"sources",g);
#endif

  stml_grid_print(g);

  stml_grid_free(g);
  stml_multilayer_free(p);
}
